@@ -6,10 +6,15 @@ use Catmandu::Importer::AlephX;
 use Data::Dumper;
 use open qw(:std :utf8);
 
+my $i = 1;
 Catmandu::Importer::AlephX->new(
   url => 'http://aleph.ugent.be/X',
-  query => 'WRD=(art)',
+  query => 'WRD=(all)',
   base => 'usm01',
+  include_items => 0,
+  limit => 5
 )->each(sub{
-  print Dumper(shift);
+  my $record = shift;
+  #print Dumper($record);
+  say ($i++);
 });
