@@ -11,9 +11,7 @@ my $aleph = Catmandu::AlephX->new(url => "http://aleph.ugent.be/X");
 my($library,$item_barcode)=("usm50","293");
 my $readitem = $aleph->read_item(library=>$library,item_barcode=>$item_barcode);
 if($readitem->is_success){
-  for my $z30(@{ $readitem->z30 }){
-    print Dumper($z30);
-  }
+  print Dumper($readitem->z30);
 }else{
-  say STDERR $readitem->error;
+  say STDERR join('',@{$readitem->errors});
 } 
