@@ -1,6 +1,6 @@
 package Catmandu::AlephX::Op::GetHolding;
 use Catmandu::Sane;
-use Data::Util qw(:check :validate);
+use Catmandu::Util qw(:check :is);
 use Moo;
 
 with('Catmandu::AlephX::Response');
@@ -9,7 +9,7 @@ has cdl_holdings => (
   is => 'ro',
   lazy => 1,
   isa => sub{
-    array_ref($_[0]);
+    check_array_ref($_[0]);
   },
   default => sub {
     [];
@@ -28,11 +28,12 @@ sub parse {
   for my $ch($xpath->find("/$op/cdl-holdings")->get_nodelist()){
     push @cdl_holdings,get_children($ch,1);
   }    
-
+  
   __PACKAGE__->new(
     cdl_holdings => \@cdl_holdings,
     session_id => $xpath->findvalue("/$op/session-id"),
-    error => $xpath->findvalue("/$op/error"),
+    errors => $class->parse_errors($xpath),
+    content_ref => $str_ref
   );
 }
 
